@@ -494,7 +494,7 @@ show_device_info_cb( void *data )
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (info), TRUE);
 	gtk_dialog_set_default_response (GTK_DIALOG (info), GTK_RESPONSE_CLOSE);
 
-	vbox1 =  GTK_DIALOG (info)->vbox;
+	vbox1 =  gtk_dialog_get_content_area (GTK_DIALOG (info));
 	gtk_widget_show (vbox1);
 
 	table1 = gtk_table_new (15, NumDevices+1, TRUE);
@@ -533,7 +533,7 @@ show_device_info_cb( void *data )
 		y = 1;
 		while ( labels[y] ) {
 			ck1 = gtk_check_button_new();
-			GTK_WIDGET_UNSET_FLAGS (ck1, GTK_CAN_FOCUS);
+			gtk_widget_set_can_focus (ck1, FALSE);
 			gtk_widget_set_sensitive (ck1, FALSE);
 
 			if ( (y <= 8) && (dev->hints[0] & 1<<(y-1)) )
@@ -553,14 +553,14 @@ show_device_info_cb( void *data )
 	}
 
 	/* Create close button */
-	aa1 = GTK_DIALOG (info)->action_area;
+	aa1 = gtk_dialog_get_action_area (GTK_DIALOG (info));
 	gtk_widget_show (aa1);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (aa1), GTK_BUTTONBOX_END);
 
 	close = gtk_button_new_from_stock ("gtk-close");
 	gtk_widget_show (close);
 	gtk_dialog_add_action_widget (GTK_DIALOG (info), close, GTK_RESPONSE_CLOSE);
-	GTK_WIDGET_SET_FLAGS (close, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (close, TRUE);
 
 	g_signal_connect (GTK_OBJECT (info), "response",
 			    G_CALLBACK (on_dialog_response),
@@ -642,7 +642,7 @@ GtkWidget* show_log_file( void *data )
 
 	frame = gtk_frame_new( _("<b>Transfers History</b>") );
 	gtk_frame_set_shadow_type (GTK_FRAME(frame), GTK_SHADOW_NONE);
-	gtk_container_add (GTK_CONTAINER(GTK_DIALOG (dialog)->vbox), frame);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), frame);
 
 	// Frame Label
 	gtk_label_set_use_markup( GTK_LABEL( gtk_frame_get_label_widget (GTK_FRAME(frame))), TRUE );
@@ -667,7 +667,7 @@ GtkWidget* show_log_file( void *data )
 
     	// Buttons
     	button_clear = gtk_button_new_from_stock( GTK_STOCK_CLEAR );
-	gtk_container_add(GTK_CONTAINER(GTK_DIALOG (dialog)->action_area), button_clear);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (dialog))), button_clear);
 
 	button_close = gtk_button_new_from_stock( GTK_STOCK_CLOSE );
 	gtk_dialog_add_action_widget(GTK_DIALOG (dialog), button_close, GTK_RESPONSE_CLOSE);
