@@ -20,24 +20,32 @@
 #ifndef __IRDA_MISC_H__
 #define __IRDA_MISC_H__
 
-#include <sys/socket.h>
-#include <linux/types.h>
-#include <linux/irda.h>
+#include <glib-2.0/glib.h>
+
 struct _dev_info
 {
         gchar *name;
-        gint hints[2];
-        struct _dev_info *next;
+        gchar *icon;
+        guint32 daddr;
+        guint32 saddr;
+        guint8 hints[2];
 };
 
-struct irda_device_list* irda_discover_device( int sfd );
-struct _dev_info *irda_get_hints( gint *num );
-int irda_check();
+typedef struct _dev_info dev_info;
+
+#define MAX_DEVICES 10
+
+GList*
+irda_discover_devices ();
+
+gchar*
+get_icon_from_irda_hints (guint8 hints[2]);
+
+void
+free_devices_list (GList *dev_list);
+
+//int
+//irda_check();
 
-#ifdef ENABLE_OPENOBEX
-gint irda_obex_init( obex_t *handle );
-gint irda_obex_send_file( obex_t *handle );
-gint irda_obex_recieve_file( obex_t *handle );
-#endif
 
 #endif
