@@ -112,7 +112,7 @@ struct ProgressWindow* progress_window_new(char* filename, void* abortfunc, void
 void progress_window_destroy(struct ProgressWindow* window)
 {
 	gtk_widget_destroy(window->handle);
-	free(window);
+	g_free(window);
 }
 
 void progress_window_update(struct ProgressWindow* window, int current, int total, double rate)
